@@ -39,9 +39,9 @@ export G4PARTICLEHPDATA=$DATAPATH/G4TENDL1.4
 # Remove previous log directory
 rm -fr $OUTDIR
 
-# Lists in 11.2
+# Lists in 11.3
 #
-for PHYSICS_LIST in FTFP_BERT FTFP_BERT_TRV FTFP_BERT_ATL FTFP_BERT_HP FTFQGSP_BERT FTFP_INCLXX FTFP_INCLXX_HP FTF_BIC LBE QBBC QGSP_BERT QGSP_BERT_HP QGSP_BIC QGSP_BIC_HP QGSP_BIC_AllHP QGSP_FTFP_BERT QGSP_INCLXX QGSP_INCLXX_HP QGS_BIC Shielding ShieldingLEND ShieldingM NuBeam Shielding_HP ShieldingM_HP FTFP_BERT_HPT FTFP_INCLXX_HPT QGSP_BERT_HPT QGSP_BIC_HPT QGSP_BIC_AllHPT QGSP_INCLXX_HPT Shielding_HPT ShieldingM_HPT
+for PHYSICS_LIST in FTFP_BERT FTFP_BERT_TRV FTFP_BERT_ATL FTFP_BERT_HP FTFQGSP_BERT FTFP_INCLXX FTFP_INCLXX_HP FTF_BIC LBE QBBC QGSP_BERT QGSP_BERT_HP QGSP_BIC QGSP_BIC_HP QGSP_BIC_AllHP QGSP_FTFP_BERT QGSP_INCLXX QGSP_INCLXX_HP QGS_BIC Shielding ShieldingLEND ShieldingLIQMD ShieldingM NuBeam Shielding_HP ShieldingLIQMD_HP ShieldingM_HP FTFP_BERT_HPT FTFP_INCLXX_HPT QGSP_BERT_HPT QGSP_BIC_HPT QGSP_BIC_AllHPT QGSP_INCLXX_HPT Shielding_HPT ShieldingLIQMD_HPT ShieldingM_HPT
 do
   for EM in _EMV _EMX _EMY _EMZ _LIV _PEN __GS __SS _EM0 _WVI __LE
   do
