@@ -15,7 +15,7 @@
 ///
 /// \author I. Hrivnacova; IPN, Orsay
 
-#define GEANT4_VMC_RELEASE "6.6.p1"
-#define GEANT4_VMC_RELEASE_DATE "13 March 2024"
+#define GEANT4_VMC_RELEASE "6.7.p1"
+#define GEANT4_VMC_RELEASE_DATE "1 April 2025"
 
 #endif // TG4_VERSION_H
