@@ -51,9 +51,14 @@ void TG4RegionsManager2::DefineRegions()
   auto g4RegionStore = G4RegionStore::GetInstance();
 
   // Get world volume & material
-  auto worldLV = TG4GeometryServices::Instance()->GetWorld()->GetLogicalVolume();
+  auto worldPV = TG4GeometryServices::Instance()->GetWorld();
+  auto worldLV = worldPV->GetLogicalVolume();
   auto worldMaterial = worldLV->GetMaterial();
 
+  // Get default production cuts
+  auto defaultProductionCuts
+    = G4ProductionCutsTable::GetProductionCutsTable()->GetDefaultProductionCuts();
+
   // Define region for each logical volume
   G4int counter = 0;
   auto lvStore = G4LogicalVolumeStore::GetInstance();
@@ -81,6 +86,8 @@ void TG4RegionsManager2::DefineRegions()
         lv->GetRegion()->GetName() == materialName) {
         if (VerboseLevel() > 1) {
            G4cout << "   "
+                  // << lv->GetRegion() << " "
+                  // << lv->GetRegion()->GetName()
                   << "has already region set, skipping" << G4endl;
         }
         continue;
@@ -110,9 +117,16 @@ void TG4RegionsManager2::DefineRegions()
     }
     region = new G4Region(regionName);
     region->AddRootLogicalVolume(lv);
+    region->UsedInMassGeometry(true);
+    region->SetProductionCuts(defaultProductionCuts);
     ++counter;
   }
 
+  // Update material lists in regions
+  // (to make the regions ready for UpdateProductionCutsTable by us
+  //  as this happens earlier then G4RunManagerKernel::UpdateRegion() call)
+  g4RegionStore->UpdateMaterialList(worldPV);
+
   if (fIsCheck) {
     CheckRegionsInGeometry();
   }
@@ -148,9 +162,18 @@ void TG4RegionsManager2::UpdateProductionCutsTable()
   // G4cout << "g4ProductionCutsTable size: " << g4ProductionCutsTable->GetTableSize() << G4endl;
 
   // update table (create materials cut couples)
-  g4ProductionCutsTable->CreateCoupleTables(); 
+  g4ProductionCutsTable->CreateCoupleTables();
   // G4cout << "g4ProductionCutsTable size after update: " << g4ProductionCutsTable->GetTableSize() << G4endl;
 
+#if G4VERSION_NUMBER <= 1130
+  // reset materials to force cuts recalculation
+  for (std::size_t i = 0; i < g4ProductionCutsTable->GetTableSize(); ++i) {
+    auto couple = const_cast<G4MaterialCutsCouple*>(g4ProductionCutsTable->GetMaterialCutsCouple(i));
+    auto material = couple->GetMaterial();
+    couple->SetMaterial(material);
+  }
+#endif
+
   for (std::size_t i = 0; i < g4ProductionCutsTable->GetTableSize(); ++i) {
     auto couple = g4ProductionCutsTable->GetMaterialCutsCouple(i);
     auto material = couple->GetMaterial();
